<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Luk (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Fold sammen</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Fold ud</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Afvis alarm</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln ord</numerusform>
            <numerusform>%Ln ord</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minut</numerusform>
            <numerusform>%Ln minutter</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% af %Ln minut</numerusform>
            <numerusform>%L1% af %Ln minutter</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% af %Ln ord</numerusform>
            <numerusform>%L1% af %Ln ord</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Dagligt fremskridt</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Længste stræk</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Nuværende stræk</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dag</numerusform>
            <numerusform>%n dage</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% af dagligt mål</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Vælg sprog</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Unavngivet %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (skrivebeskyttet)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Beklager</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Det er ikke muligt at gemme &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Gem fil som</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Det er ikke muligt at overskrive &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Omdøb fil</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Det er ikke muligt at omdøbe &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Genindlæs fil?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Genindlæs filen &apos;%1&apos; fra disken?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Alle ændringer, der ikke er gemt, vil gå tabt.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Genindlæs</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Unavngivet %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Gemmes der som ren tekst, vil al formatting blive fjernet. Fjern formattering?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Fil ændret</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Filen &apos;%1&apos; blev ændret af et andet program.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Ønsker du at genindlæse filen?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Genindlæs</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Fil slettet</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Filen %1 blev slettet af et andet program.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Ønsker du at gemme eller lukke filen?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Kunne ikke åbne arkivet.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Søg efter:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Erstat med:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignorer store/små bogstaver</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Kun hele ord</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Regulære udtryk</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Søg tilbage</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Søg fremad</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Find</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Erstat</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Erstat &amp;alle</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Find</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Erstat</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Erstat %n forekomst?</numerusform>
            <numerusform>Erstat %n forekomster?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Beklager</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Frasen kunne ikke findes.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Ren tekst</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Alle understøttede filer</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument flad XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Stavekontrol...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Der er ikke fundet forslag)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Åbn billede</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Billeder</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vælg programmets sprog:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemsprog&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Note</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Genstart programmet for at skifte til det valgte sprog.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Kunne ikke åbne arkivet.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Værktøjslinie</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Stavekontrol</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Vælg ordbog</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Beklager</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Det er ikke muligt at åbne arkivet.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Dette arkiv indeholder ikke en anvendelig ordbog.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Genveje</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>En eller flere genveje er i konflikt. Ønsker du at fortsætte?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Ordbogen &apos;%1&apos; findes allerede. Ønsker du at erstatte den?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Dagligt mål</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Intet</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minutter:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Ord:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Redigering</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Altid centreret lodret</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Firkantet markør for indsættelse</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Udjævn skrifttyper</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Skrivemaskinelyde</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Smart quotes:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dobbelte</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enkelte</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scener</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Separator:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Gemmer</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Husk markørens placering</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Optælling af ord</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Antal sider</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Antal afsnit</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Antal tegn</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Tegn:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Afsnit:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritme til ordtælling</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Nulstil dagligt fremskridt for i dag?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Indlæg Byte Order Mark i de rene tekstfiler</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Standardformat:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Nulstil i dag</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historik</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Husk historik</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Vis stræk</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minimumsfremskridt for stræk:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Registrer ordgrænser</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Del antal tegn med seks</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Tæl hvert bogstav som et ord</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritme for sideoptælling</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Kun ikoner</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Kun tekst</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Tekst ved siden af ikoner</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Tekst under ikoner</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Placering i tekst</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Handlinger</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Flyt op</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Flyt ned</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Tilføj opdeling</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Genvej</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Handling</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Kontroller stavning, mens der skrives</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignorer STORE BOGSTAVER</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignorer ord med tal</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprog</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Personlig ordbog</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Fjern nuværende mappe?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Brugerflade</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Vis altid scrollbar</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Vis altid øverste bjælke</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Vis altid nederste bjælke</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Ikke en understøttet RTF-fil.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Uventet slutning på filen.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Ned</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Flyt scener op</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Op</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Liste over scener til/fra</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Vis liste over scener (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Skjul liste over scener (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Flyt scener ned</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Juster liste over scener</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Administrer sessioner</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;essioner</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplik</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Skift til</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Ny session</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duplik af session</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Omdøb session</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Slet valgte session?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Navn på session:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Beklager</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Der gøres allerede brug af det ønskede sessionsnavn.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Ny...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Administrer</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Ryd</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Nulstil</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Genvej:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Erstatter citatonstegn...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Vent venligst</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Kontroller stavning</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Tilføj</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorer</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnorer alle</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Skift</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>S&amp;kift alle</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Ikke i ordbogen:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Skift til:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Kontrollerer stavning...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Vent venligst</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Begynd check ved start på filen?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Stavekontrol fuldført.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symboler</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Nyligt brugte symboler</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Alle symboler</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detaljer</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Indsæt</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blokke</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Uden titel %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Intet billede</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Side om side</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centreret</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Strakt</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Skaleret</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Zoomet</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Gennemsigtighed:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Bredde:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Runde hjørner på tekstbaggrund</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Radius:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Slør tekstbaggrund</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Skygge på tekstbaggrund</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Lodret afsæt:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Margener</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Vindue:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>ide:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Indryk første linie</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Over:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Under:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Rediger tema</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Baggrund for vindue</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farve:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Billede:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> pixels</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Tekstbaggrund</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Skrifttype:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Stavefejl:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Linjeafstand</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enkel</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>Halvanden linie</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dobbelt</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proportionel</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Højde:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Mellemrum mellem afsnit</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Fanebredde:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nyt tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temaer</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Gentle Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Old School</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Space Dreams</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Writing Desk</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nyt</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplik</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Tilpasset</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>let</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Slet temaet &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Temaer (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importer tema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Eksporter tema</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Bitter Skies</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Enchantment</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Spy Games</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Tranquility</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Slet tæller</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Ord:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Sider:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Afsnit:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Tegn:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Sæt nedtælling</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Sæt tid</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Nedtælling:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tid:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>TT:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>TT:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Ingen aktive tællere</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Tællere</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Nylig</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørgsmål</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Fortryd ændring af tællere</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+TT:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Indlæser temaer</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Indlæser lyde</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Uden titel</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Åbn fil</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Om FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Et enkelt tekstbehandlingsprogram i fuld skærm</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Udgivet under licensen &lt;a href=%1&gt;GPL 3&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Anvender ikoner fra &lt;a href=%1&gt;Oxygen&lt;/a&gt;-temaet</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Anvendes under  licensen &lt;a href=%1&gt;LGPL 3&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Tegn: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Sider: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Afsnit: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Ord: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Åbner %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Uden titel%1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Liste over alle dokumenter</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Skift til næste dokument</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Skift til tidligere dokument</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Skift til første dokument</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Skift til sidste dokument</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Skift til dokument %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Indlæser indstillinger</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Der kan ikke skrives til reservecachen.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter blev ikke lukket korrekt.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Gendan fra reservecache?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Visse filer kunne ikke åbnes.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Visse filer blev åbnet skrivebeskyttet.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; er nyere end den lagrede kopi.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Overskriv nyere fil?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Gem ændringer</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Gem ændringerne til filen &apos;%1&apos;, inden den lukkes?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Dine ændringer vil gå tabt, hvis du ikke gemmer dem.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Kan ikke indlæse skrivemaskinelyde.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Åbn...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Genind&amp;læs</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Gem</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Gem &amp;som</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Omdøb...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Gem &amp;alle</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Administrer sessioner</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Ny session</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Udskrift...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Fortryd</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Gendan</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>K&amp;lip</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopier</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Indsæt</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Indsæt &amp;uformatteret</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Vælg &amp;alle</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Vælg &amp;scene</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmat</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Fed</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Kursiv</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Understreg</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Gennemstreg</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Hævet skrift</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Sænket skrift</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>&amp;Venstrestil</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Centrer</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>&amp;Højrestil</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Tilpasset</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Forminds indrykning</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Fo&amp;røg indrykning</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Tekstblok med Ve&amp;nstre til højre</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Tekstblok med Hø&amp;jre til venstre</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Værktøjer</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Find...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Find &amp;næste</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Find &amp;tidligere</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Erstat</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Smart &amp;Quotes</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Opdater &amp;dokument</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Opdater &amp;markering</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Stavning...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Sæt &amp;sprog</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Tællere...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymboler...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Dagligt fremskridt</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Indstillinger</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Vis &amp;værktøjslinie</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Vis &amp;menuikoner</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>F&amp;okuseret tekst</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Fuld skærm</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimer</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Temaer...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Indstillinger...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Fokus fra</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Fokus én linie</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Fokus tre linier</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>A&amp;fsnit</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Fokus afsnit</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programmets &amp;sprog</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Nogle filer var ikke understøttede og kunne ikke åbnes.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Fra</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>En &amp;linie</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tre linier</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;QT</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Si&amp;deopsætning...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Overskrift</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Overskrift &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Overskrift &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Overskrift &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Overskrift &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Overskrift &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Overskrift &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Opdater dokumentet med Smart Quotes</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Opdater markeringen med Smart Quotes</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
